@@ -167,6 +167,65 @@ def general_cs():
     return out_dict, pol_status, pol_theta, ret_status, ret_theta, dark_status
 
 
+@pytest.fixture(scope="session")
+def global_cs():
+    # Make up a Calibration sequence. Mostly random except for two clears and two darks at start and end, which
+    # we want to test
+    pol_status = [
+        "clear",
+        "clear",
+        "Sapphire Polarizer",
+        "Sapphire Polarizer",
+        "Sapphire Polarizer",
+        "clear",
+        "clear",
+    ]
+    pol_theta = [0.0, 0.0, 60.0, 0.0, 120.0, 0.0, 0.0]
+    ret_status = ["clear", "clear", "clear", "SiO2 SAR", "clear", "clear", "clear"]
+    ret_theta = [0.0, 0.0, 0.0, 45.0, 0.0, 0.0, 0.0]
+    dark_status = [
+        "DarkShutter",
+        "FieldStop (5arcmin)",
+        "FieldStop (5arcmin)",
+        "FieldStop (5arcmin)",
+        "FieldStop (5arcmin)",
+        "FieldStop (5arcmin)",
+        "DarkShutter",
+    ]
+    num_steps = len(pol_theta)
+    out_dict = dict()
+    start_time = None
+    for n in range(num_steps):
+        ds = CalibrationSequenceStepDataset(
+            array_shape=(1, 2, 2),
+            time_delta=2.0,
+            pol_status=pol_status[n],
+            pol_theta=pol_theta[n],
+            ret_status=ret_status[n],
+            ret_theta=ret_theta[n],
+            dark_status=dark_status[n],
+            start_time=start_time,
+        )
+        header_list = [
+            spec122_validator.validate_and_translate_to_214_l0(
+                d.header(), return_type=fits.HDUList
+            )[0].header
+            for d in ds
+        ]
+        hdu_list = []
+        for m in range(ds.num_mod):
+            hdu_list.append(
+                fits.PrimaryHDU(
+                    data=np.ones((1, 1, 1)) * n + 100 * m, header=fits.Header(header_list.pop(0))
+                )
+            )
+
+        out_dict[n] = [InstAccess(h) for h in hdu_list]
+        start_time = ds.start_time + datetime.timedelta(seconds=60)
+
+    return out_dict, pol_status, pol_theta, ret_status, ret_theta, dark_status
+
+
 @pytest.fixture
 def general_drawer(general_cs) -> Drawer:
     out_dict = general_cs[0]
@@ -180,6 +239,15 @@ def general_dresser(general_drawer) -> Dresser:
     return dresser
 
 
+@pytest.fixture
+def global_dresser(global_cs) -> Dresser:
+    out_dict = global_cs[0]
+    dresser = Dresser()
+    dresser.add_drawer(Drawer(out_dict))
+
+    return dresser
+
+
 @pytest.fixture(scope="session")
 def session_dresser(general_cs) -> Dresser:
     dresser = Dresser()
